@@ -1,4 +1,4 @@
-from .shared import validate_dates, validate_country, \
+from .shared import validate_dates, validate_region, validate_country, \
     need_validate_coordinates, validate_coordinates, \
     validate_area, need_validate_area
 
@@ -12,9 +12,23 @@ def validate_organisation_dates(organisation: dict):
 
 
 def validate_organisation(organisation: dict):
+    """
+    Validates a single `Organisation`.
+
+    Parameters
+    ----------
+    organisation : dict
+        The `Organisation` to validate.
+
+    Returns
+    -------
+    List
+        The list of errors for the `Organisation`, which can be empty if no errors detected.
+    """
     return [
         validate_organisation_dates(organisation),
         validate_country(organisation) if 'country' in organisation else True,
+        validate_region(organisation) if 'region' in organisation else True,
         validate_coordinates(organisation) if need_validate_coordinates(organisation) else True,
         validate_area(organisation) if need_validate_area(organisation) else True
     ]
