@@ -2,7 +2,7 @@ from typing import List
 import re
 
 from hestia_earth.validation.geojson import _get_geojson_area
-from hestia_earth.validation.gadm import _get_gadm_data
+from hestia_earth.validation.gee import _get_region_id
 from hestia_earth.validation.utils import _filter_list_errors, _next_error, _same_properties, _value_average
 
 
@@ -127,11 +127,14 @@ def validate_coordinates(node: dict, region_key='region'):
     country = node.get('country', {})
     region = node.get(region_key)
     gadm_id = region.get('@id') if region else country.get('@id')
-    id = _get_gadm_data(gadm_id, id=gadm_id, latitude=latitude, longitude=longitude).get('id')
-    return (region and region.get('@id') == id) or (country.get('@id') == id) or {
+    id = _get_region_id(gadm_id, latitude=latitude, longitude=longitude)
+    return gadm_id == id or {
         'level': 'error',
         'dataPath': f".{region_key}" if region else '.country',
-        'message': 'does not contain latitude and longitude'
+        'message': 'does not contain latitude and longitude',
+        'params': {
+            'gadmId': id
+        }
     }
 
 
